@@ -76,7 +76,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #endif
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
 #ifdef GWENVIEW_SEMANTICINFO_BACKEND_NEPOMUK
-#include <nepomuk/resourcemanager.h>
+#include <Nepomuk2/ResourceManager>
 #endif
 #include "semanticinfocontextmanageritem.h"
 #endif
@@ -90,15 +90,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <lib/archiveutils.h>
 #include <lib/document/documentfactory.h>
 #include <lib/eventwatcher.h>
+#include <lib/gvdebug.h>
 #include <lib/gwenviewconfig.h>
+#include <lib/graphicshudlabel.h>
+#include <lib/graphicshudwidget.h>
 #include <lib/mimetypeutils.h>
 #include <lib/print/printhelper.h>
 #include <lib/slideshow.h>
 #include <lib/signalblocker.h>
 #include <lib/semanticinfo/sorteddirmodel.h>
+#include <lib/thumbnailprovider/thumbnailprovider.h>
 #include <lib/thumbnailview/thumbnailbarview.h>
 #include <lib/thumbnailview/thumbnailview.h>
-#include <lib/thumbnailloadjob.h>
 #include <lib/urlutils.h>
 
 namespace Gwenview
@@ -164,8 +167,10 @@ struct MainWindow::Private
     ViewMainPage* mViewMainPage;
     KUrlNavigator* mUrlNavigator;
     ThumbnailView* mThumbnailView;
+    ThumbnailView* mActiveThumbnailView;
     DocumentInfoProvider* mDocumentInfoProvider;
     ThumbnailViewHelper* mThumbnailViewHelper;
+    QPointer<ThumbnailProvider> mThumbnailProvider;
     BrowseMainPage* mBrowseMainPage;
     StartMainPage* mStartMainPage;
     SideBar* mSideBar;
@@ -487,7 +492,7 @@ struct MainWindow::Private
         // only if Nepomuk is available
         // When using Fake backend always create it
 #ifdef GWENVIEW_SEMANTICINFO_BACKEND_NEPOMUK
-        if (Nepomuk::ResourceManager::instance()->init() == 0) {
+        if (Nepomuk2::ResourceManager::instance()->init() == 0) {
 #endif
             semanticInfoItem = new SemanticInfoContextManagerItem(mContextManager, actionCollection, mViewMainPage);
 #ifdef GWENVIEW_SEMANTICINFO_BACKEND_NEPOMUK
@@ -586,11 +591,21 @@ struct MainWindow::Private
         mPreloadDirectionIsForward = offset > 0;
         QModelIndex index = currentIndex();
         index = mDirModel->index(index.row() + offset, 0);
-        if (!index.isValid()) {
-            return;
-        }
-        if (!indexIsDirOrArchive(index)) {
+        if (index.isValid() && !indexIsDirOrArchive(index)) {
             goTo(index);
+        } else {
+            if (offset > 0) {
+                goToFirstDocument();
+            } else {
+                goToLastDocument();
+            }
+            if (mCurrentMainPageId == ViewMainPageId) {
+                showMessageBubble(
+                    offset > 0
+                    ? i18n("Last document reached, continuing on first document.")
+                    : i18n("First document reached, continuing on last document.")
+                );
+            }
         }
     }
 
@@ -616,6 +631,19 @@ struct MainWindow::Private
         goTo(index);
     }
 
+    void showMessageBubble(const QString &message)
+    {
+        GraphicsHudWidget* hud = new GraphicsHudWidget;
+        GraphicsHudLabel* label = new GraphicsHudLabel;
+        label->setText(message);
+        hud->init(label, GraphicsHudWidget::OptionNone);
+        hud->setContentsMargins(6, 6, 6, 6);
+        hud->setAutoDeleteOnFadeout(true);
+        QTimer::singleShot(2000, hud, SLOT(fadeOut()));
+
+        mViewMainPage->showMessageWidget(hud, Qt::AlignCenter);
+    }
+
     void spreadCurrentDirUrl(const KUrl& url)
     {
         mContextManager->setCurrentDirUrl(url);
@@ -731,10 +759,7 @@ struct MainWindow::Private
 
     void setUrlToSelect(const KUrl& url)
     {
-        if (!url.isValid()) {
-            kWarning() << "called with an invalid url, this should not happen!";
-            return;
-        }
+        GV_RETURN_IF_FAIL(url.isValid());
         mUrlToSelect = url;
         updateContextDependentComponents();
         selectUrlToSelect();
@@ -760,12 +785,12 @@ struct MainWindow::Private
     }
 
     const char* sideBarConfigGroupName() const
- {
+    {
         const char* name = 0;
         switch (mCurrentMainPageId) {
         case StartMainPageId:
-            kWarning() << "Should not happen!";
-            // Fall through
+            GV_WARN_AND_RETURN_VALUE(BROWSE_MODE_SIDE_BAR_GROUP, "mCurrentMainPageId == 'StartMainPageId'");
+            break;
         case BrowseMainPageId:
             name = BROWSE_MODE_SIDE_BAR_GROUP;
             break;
@@ -811,6 +836,35 @@ struct MainWindow::Private
             mNotificationRestrictions = 0;
         }
     }
+
+    void assignThumbnailProviderToThumbnailView(ThumbnailView* thumbnailView)
+    {
+        GV_RETURN_IF_FAIL(thumbnailView);
+        if (mActiveThumbnailView) {
+            mActiveThumbnailView->setThumbnailProvider(0);
+        }
+        thumbnailView->setThumbnailProvider(mThumbnailProvider);
+        mActiveThumbnailView = thumbnailView;
+        if (mActiveThumbnailView->isVisible()) {
+            mThumbnailProvider->stop();
+            mActiveThumbnailView->generateThumbnailsForItems();
+        }
+    }
+
+    void autoAssignThumbnailProvider()
+    {
+        if (mCurrentMainPageId == ViewMainPageId) {
+            if (q->windowState() & Qt::WindowFullScreen) {
+                assignThumbnailProviderToThumbnailView(mFullScreenContent->thumbnailBar());
+            } else {
+                assignThumbnailProviderToThumbnailView(mViewMainPage->thumbnailBar());
+            }
+        } else if (mCurrentMainPageId == BrowseMainPageId) {
+            assignThumbnailProviderToThumbnailView(mThumbnailView);
+        } else if (mCurrentMainPageId == StartMainPageId) {
+            assignThumbnailProviderToThumbnailView(mStartMainPage->recentFoldersView());
+        }
+    }
 };
 
 MainWindow::MainWindow()
@@ -823,6 +877,8 @@ MainWindow::MainWindow()
     d->mGvCore = new GvCore(this, d->mDirModel);
     d->mPreloader = new Preloader(this);
     d->mNotificationRestrictions = 0;
+    d->mThumbnailProvider = new ThumbnailProvider();
+    d->mActiveThumbnailView = 0;
     d->initDirModel();
     d->setupWidgets();
     d->setupActions();
@@ -848,6 +904,7 @@ MainWindow::MainWindow()
 
 MainWindow::~MainWindow()
 {
+    delete d->mThumbnailProvider;
     delete d;
 }
 
@@ -962,6 +1019,7 @@ void MainWindow::setActiveViewModeAction(QAction* action)
         setCaption(QString());
     }
     d->loadSideBarConfig();
+    d->autoAssignThumbnailProvider();
 
     emit viewModeChanged();
 }
@@ -1039,10 +1097,7 @@ void MainWindow::openSelectedDocuments()
     if (currentUrl.isEmpty()) {
         // Current index is not selected, or it is not a document: set
         // firstDocumentIndex as current
-        if (!firstDocumentIndex.isValid()) {
-            kWarning() << "firstDocumentIndex is invalid. This should not happen!";
-            return;
-        }
+        GV_RETURN_IF_FAIL(firstDocumentIndex.isValid());
         d->mThumbnailView->selectionModel()->setCurrentIndex(firstDocumentIndex, QItemSelectionModel::Current);
         currentUrl = urls.first();
     }
@@ -1076,6 +1131,8 @@ void MainWindow::showStartMainPage()
     d->updateActions();
     updatePreviousNextActions();
     d->updateContextDependentComponents();
+
+    d->autoAssignThumbnailProvider();
 }
 
 void MainWindow::slotStartMainPageUrlSelected(const KUrl& url)
@@ -1117,6 +1174,7 @@ void MainWindow::openDirUrl(const KUrl& url)
         urlToSelect.setPath(pathToSelect);
         d->setUrlToSelect(urlToSelect);
     }
+    d->mThumbnailProvider->stop();
     d->mDirModel->dirLister()->openUrl(url);
     d->spreadCurrentDirUrl(url);
     d->mGvCore->addUrlToRecentFolders(url);
@@ -1277,15 +1335,17 @@ void MainWindow::goToUrl(const KUrl& url)
 
 void MainWindow::updatePreviousNextActions()
 {
-    QModelIndex index = d->currentIndex();
+    int row = d->currentIndex().row();
+    QModelIndex prevIndex = d->mDirModel->index(row - 1, 0);
+    QModelIndex nextIndex = d->mDirModel->index(row + 1, 0);
+    bool hasPrevious = prevIndex.isValid() && !d->indexIsDirOrArchive(prevIndex);
+    bool hasNext = nextIndex.isValid() && !d->indexIsDirOrArchive(nextIndex);
+    bool canBrowse = hasPrevious | hasNext;
 
-    QModelIndex prevIndex = d->mDirModel->index(index.row() - 1, 0);
-    d->mGoToPreviousAction->setEnabled(prevIndex.isValid() && !d->indexIsDirOrArchive(prevIndex));
-    d->mGoToFirstAction->setEnabled(d->mGoToPreviousAction->isEnabled());
-
-    QModelIndex nextIndex = d->mDirModel->index(index.row() + 1, 0);
-    d->mGoToNextAction->setEnabled(nextIndex.isValid() && !d->indexIsDirOrArchive(nextIndex));
-    d->mGoToLastAction->setEnabled(d->mGoToNextAction->isEnabled());
+    d->mGoToPreviousAction->setEnabled(canBrowse);
+    d->mGoToNextAction->setEnabled(canBrowse);
+    d->mGoToFirstAction->setEnabled(hasPrevious);
+    d->mGoToLastAction->setEnabled(hasNext);
 }
 
 void MainWindow::leaveFullScreen()
@@ -1349,6 +1409,7 @@ void MainWindow::toggleFullScreen(bool checked)
         d->mFullScreenLeftAt = QDateTime::currentDateTime();
     }
     setUpdatesEnabled(true);
+    d->autoAssignThumbnailProvider();
 }
 
 void MainWindow::saveCurrent()
@@ -1480,7 +1541,7 @@ bool MainWindow::queryClose()
 bool MainWindow::queryExit()
 {
     if (GwenviewConfig::deleteThumbnailCacheOnExit()) {
-        const QString dir = ThumbnailLoadJob::thumbnailBaseDir();
+        const QString dir = ThumbnailProvider::thumbnailBaseDir();
         if (QFile::exists(dir)) {
             KIO::NetAccess::del(KUrl::fromPath(dir), this);
         }
