@@ -48,6 +48,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <lib/documentview/documentviewcontainer.h>
 #include <lib/documentview/documentviewcontroller.h>
 #include <lib/documentview/documentviewsynchronizer.h>
+#include <lib/gvdebug.h>
 #include <lib/gwenviewconfig.h>
 #include <lib/paintutils.h>
 #include <lib/semanticinfo/sorteddirmodel.h>
@@ -158,7 +159,6 @@ struct ViewMainPagePrivate
     QHash<DocumentView*, KActivities::ResourceInstance*> mActivityResources;
 
     bool mFullScreenMode;
-    QPalette mNormalPalette;
     bool mCompareMode;
     bool mThumbnailBarVisibleBeforeFullScreen;
 
@@ -173,9 +173,11 @@ struct ViewMainPagePrivate
 
     void setupThumbnailBarStyleSheet()
     {
+        QPalette pal = mGvCore->palette(GvCore::NormalViewPalette);
+        mThumbnailBar->setPalette(pal);
         Qt::Orientation orientation = mThumbnailBar->orientation();
-        QColor bgColor = mNormalPalette.color(QPalette::Normal, QPalette::Window);
-        QColor bgSelColor = mNormalPalette.color(QPalette::Normal, QPalette::Highlight);
+        QColor bgColor = pal.color(QPalette::Normal, QPalette::Base);
+        QColor bgSelColor = pal.color(QPalette::Normal, QPalette::Highlight);
 
         // Avoid dark and bright colors
         bgColor.setHsv(bgColor.hue(), bgColor.saturation(), (127 + 3 * bgColor.value()) / 4);
@@ -184,11 +186,6 @@ struct ViewMainPagePrivate
         QColor rightBorderColor = PaintUtils::adjustedHsv(bgColor, 0, 0, -qMin(40, bgColor.value()));
         QColor borderSelColor = PaintUtils::adjustedHsv(bgSelColor, 0, 0, -qMin(60, bgSelColor.value()));
 
-        QString viewCss =
-            "#thumbnailBarView {"
-            "	background-color: rgba(0, 0, 0, 10%);"
-            "}";
-
         QString itemCss =
             "QListView::item {"
             "	background-color: %1;"
@@ -210,7 +207,7 @@ struct ViewMainPagePrivate
                          gradient(orientation, bgSelColor, 56),
                          rgba(borderSelColor));
 
-        QString css = viewCss + itemCss + itemSelCss;
+        QString css = itemCss + itemSelCss;
         if (orientation == Qt::Vertical) {
             css.replace("left", "top").replace("right", "bottom");
         }
@@ -754,20 +751,12 @@ void ViewMainPage::deselectView(DocumentView* view)
     if (view == d->currentView()) {
         // We need to find a new view to set as current
         int idx = d->mDocumentViews.indexOf(view);
-        // Look for the next visible view after the current one
-        for (int newIdx = idx + 1; newIdx < d->mDocumentViews.count(); ++newIdx) {
-            newCurrentView = d->mDocumentViews.at(newIdx);
-            break;
-        }
-        if (!newCurrentView) {
-            // No visible view found after the current one, look before
-            for (int newIdx = idx - 1; newIdx >= 0; --newIdx) {
-                newCurrentView = d->mDocumentViews.at(newIdx);
-                break;
-            }
-        }
-        if (!newCurrentView) {
-            kWarning() << "No view found to set as current, this should not happen!";
+        if (idx + 1 < d->mDocumentViews.count()) {
+            newCurrentView = d->mDocumentViews.at(idx + 1);
+        } else if (idx > 0) {
+            newCurrentView = d->mDocumentViews.at(idx - 1);
+        } else {
+            GV_WARN_AND_RETURN("No view found to set as current");
         }
     }
 
