@@ -63,9 +63,7 @@ struct DocumentPrivate
     ImageMetaInfoModel mImageMetaInfoModel;
     QUndoStack mUndoStack;
     QString mErrorString;
-#ifdef LCMS2_FOUND
     Cms::Profile::Ptr mCmsProfile;
-#endif
     /** @} */
 
     void scheduleImageLoading(int invertedZoom)
@@ -114,9 +112,7 @@ void Document::reload()
     d->mImageMetaInfoModel.setUrl(d->mUrl);
     d->mUndoStack.clear();
     d->mErrorString.clear();
-#ifdef LCMS2_FOUND
     d->mCmsProfile = 0;
-#endif
 
     switchToImpl(new LoadingDocumentImpl(this));
 }
@@ -135,7 +131,7 @@ const QImage& Document::image() const
 inline int invertedZoomForZoom(qreal zoom)
 {
     int invertedZoom;
-    for (invertedZoom = 1; zoom < 1. / (invertedZoom * 2); invertedZoom *= 2) {}
+    for (invertedZoom = 1; zoom < 1. / (invertedZoom * 4); invertedZoom *= 2) {}
     return invertedZoom;
 }
 
@@ -497,7 +493,6 @@ QSvgRenderer* Document::svgRenderer() const
     return d->mImpl->svgRenderer();
 }
 
-#ifdef LCMS2_FOUND
 void Document::setCmsProfile(Cms::Profile::Ptr ptr)
 {
     d->mCmsProfile = ptr;
@@ -507,6 +502,5 @@ Cms::Profile::Ptr Document::cmsProfile() const
 {
     return d->mCmsProfile;
 }
-#endif
 
 } // namespace
