@@ -34,12 +34,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KSharedPtr>
 
 // Local
-#include <config-gwenview.h>
 #include <lib/mimetypeutils.h>
-
-#ifdef LCMS2_FOUND
 #include <lib/cms/cmsprofile.h>
-#endif
 
 class QImage;
 class QRect;
@@ -173,9 +169,7 @@ public:
      */
     QByteArray rawData() const;
 
-#ifdef LCMS2_FOUND
     Cms::Profile::Ptr cmsProfile() const;
-#endif
 
     /**
      * Returns a QSvgRenderer which can be used to render this document if it is
@@ -245,9 +239,7 @@ private:
     void setDownSampledImage(const QImage&, int invertedZoom);
     void switchToImpl(AbstractDocumentImpl* impl);
     void setErrorString(const QString&);
-#ifdef LCMS2_FOUND
     void setCmsProfile(Cms::Profile::Ptr);
-#endif
 
     Document(const KUrl&);
     DocumentPrivate * const d;
