@@ -22,12 +22,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include "rasterimageview.moc"
 
 // Local
-#include <config-gwenview.h>
 #include <lib/documentview/abstractrasterimageviewtool.h>
 #include <lib/imagescaler.h>
-#ifdef LCMS2_FOUND
-#include <cms/cmsprofile.h>
-#endif
+#include <lib/cms/cmsprofile.h>
+#include <lib/gvdebug.h>
 
 // KDE
 #include <KDebug>
@@ -38,9 +36,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QTimer>
 #include <QWeakPointer>
 
-#ifdef LCMS2_FOUND
+// LCMS2
 #include <lcms2.h>
-#endif
 
 
 namespace Gwenview
@@ -70,7 +67,6 @@ struct RasterImageViewPrivate
 
     QWeakPointer<AbstractRasterImageViewTool> mTool;
 
-#ifdef LCMS2_FOUND
     cmsHTRANSFORM mDisplayTransform;
 
     void updateDisplayTransform()
@@ -102,7 +98,6 @@ struct RasterImageViewPrivate
                                                monitorProfile->handle(), cmsFormat,
                                                INTENT_PERCEPTUAL, cmsFLAGS_BLACKPOINTCOMPENSATION);
     }
-#endif
 
     void createBackgroundTexture()
     {
@@ -190,9 +185,7 @@ RasterImageView::RasterImageView(QGraphicsItem* parent)
 {
     d->q = this;
     d->mEmittedCompleted = false;
-#ifdef LCMS2_FOUND
     d->mDisplayTransform = 0;
-#endif
 
     d->mAlphaBackgroundMode = AlphaBackgroundCheckBoard;
     d->mAlphaBackgroundColor = Qt::black;
@@ -209,11 +202,9 @@ RasterImageView::RasterImageView(QGraphicsItem* parent)
 
 RasterImageView::~RasterImageView()
 {
-#ifdef LCMS2_FOUND
     if (d->mDisplayTransform) {
         cmsDeleteTransform(d->mDisplayTransform);
     }
-#endif
     delete d;
 }
 
@@ -268,14 +259,8 @@ void RasterImageView::slotDocumentMetaInfoLoaded()
 
 void RasterImageView::finishSetDocument()
 {
-    if (!document()->size().isValid()) {
-        kError() << "No valid image size available, this should not happen!";
-        return;
-    }
-
-#ifdef LCMS2_FOUND
+    GV_RETURN_IF_FAIL(document()->size().isValid());
     d->updateDisplayTransform();
-#endif
 
     d->mScaler->setDocument(document());
     d->resizeBuffer();
@@ -317,12 +302,10 @@ void RasterImageView::slotDocumentIsAnimatedUpdated()
 
 void RasterImageView::updateFromScaler(int zoomedImageLeft, int zoomedImageTop, const QImage& image)
 {
-#ifdef LCMS2_FOUND
     if (d->mDisplayTransform) {
         quint8 *bytes = const_cast<quint8*>(image.bits());
         cmsDoTransform(d->mDisplayTransform, bytes, bytes, image.width() * image.height());
     }
-#endif
 
     d->resizeBuffer();
     int viewportLeft = zoomedImageLeft - scrollPos().x();
