@@ -49,7 +49,7 @@ void UrlUtilsTest::testFixUserEnteredUrl_data()
     QString pwd = QDir::currentPath();
 
     NEW_ROW("http://example.com", "http://example.com");
-    NEW_ROW("file://" + pwd + "/example.zip", "zip://" + pwd + "/example.zip");
-    NEW_ROW("file://" + pwd + "/example.cbz", "zip://" + pwd + "/example.cbz");
+    NEW_ROW("file://" + pwd + "/example.zip", "zip:" + pwd + "/example.zip");
+    NEW_ROW("file://" + pwd + "/example.cbz", "zip:" + pwd + "/example.cbz");
     NEW_ROW("file://" + pwd + "/example.jpg", "file://" + pwd + "/example.jpg");
 }
